<?php
/**
 * @version   $Id: RokContentRotator.php 11105 2013-06-03 16:53:26Z btowles $
 * @author    RocketTheme http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2015 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

require_once (JPath::clean(JPATH_SITE . '/components/com_content/helpers/route.php'));
require_once (JPath::clean(JPATH_SITE . '/components/com_content/models/articles.php'));
if (file_exists(JPath::clean(JPATH_SITE . '/libraries/joomla/html/html/content.php'))) require_once (JPath::clean(JPATH_SITE . '/libraries/joomla/html/html/content.php'));
if(class_exists('JModelLegacy')) JModelLegacy::addIncludePath(JPATH_SITE.'/components/com_content/models', 'ContentModel');
class RokContentRotator
{
    public function loadScripts(&$params)
    {
        JHtml::_('behavior.framework', true);
        $doc = JFactory::getDocument();
        $doc->addScript(JURI::Root(true) . '/modules/mod_rokcontentrotator/rokcontentrotator.js');

        $jsinit = "window.addEvent('domready', function() {
			var crotator = new RokContentRotator({hover: " . ($params->get('click_title') == 1 ? 1 : 0) . "});
		});";

        $doc->addScriptDeclaration($jsinit);
    }

    protected function prepareContent($text, $length = 300)
    {
        // strips tags won't remove the actual jscript
        $text = preg_replace("'<script[^>]*>.*?</script>'si", "", $text);
        $text = preg_replace('/{.+?}/', '', $text);
        if (strlen($text) > $length) $text = substr($text, 0, $length);
        return $text;
    }

    /**
     * @param  JRegistry $params
     * @return array|mixed
     */
    public function _getList(&$params){
        $conf = JFactory::getConfig();
        if ($conf->get('caching') && $params->get('module_cache'))
        {
            $user = JFactory::getUser();
            $cache = JFactory::getCache('mod_rokcontentrotator');
            $cache->setCaching(true);
            $lifetime = ($params->get('module_cache') == 1 && (int)$params->get('cache_time') > 0)?(int)$params->get('cache_time'): (int)$conf->get('config.cachetime')*60;
            $cache->setLifeTime($lifetime);
            $args = array(&$params);
            $checksum = md5($params->__toString());
            $items = $cache->get(array($this, '_getList',), $args, 'mod_rokcontentrotator-' . $user->get('aid', 0) . '-' . $checksum);
        }
        else
        {
            $items = self::_getList($params);
        }
        return $items;
    }

    public function getList(&$params)
    {
        $db = JFactory::getDBO();
        $user = JFactory::getUser();
        $userId = (int)$user->get('id');

        $count = (int)$params->get('count', 5);
        $catid = $params->get('catid');
        $show_front = $params->get('show_front', 1);
        $aid = $user->get('aid', 0);
        $content_type = 'joomla';
        $ordering = $params->get('itemsOrdering');
        $cid = $params->get('category_id', NULL);
        $text_length = intval($params->get('preview_count', 75));
        $show_title = trim($params->get('show_title', 1));


        // ordering
        switch ($ordering)
        {
            case 'date' :
                $orderby = 'a.created ASC';
                break;
            case 'rdate' :
                $orderby = 'a.created DESC';
                break;
            case 'alpha' :
                $orderby = 'a.title';
                break;
            case 'ralpha' :
                $orderby = 'a.title DESC';
                break;
            case 'order' :
                $orderby = 'a.ordering';
                break;
            default :
                $orderby = 'a.id DESC';
                break;
        }

        // content specific stuff
        if ($content_type == 'joomla')
        {
            // start Joomla specific
            jimport('joomla.application.component.model');

            // Get an instance of the generic articles model
            if(class_exists('JModelLegacy')){
                $model = JModelLegacy::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
            } else {
                $model = JModel::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
            }


            // Set application parameters in model
            $appParams = JFactory::getApplication()->getParams();
            $model->setState('params', $appParams);

            // Set the filters based on the module params
            $model->setState('list.start', 0);
            $model->setState('list.limit', $count);
            $model->setState('filter.published', 1);

            // Access filter
            $access = !JComponentHelper::getParams('com_content')->get('show_noauth');
            $authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
            $model->setState('filter.access', $access);

            // Category filter
            $model->setState('filter.category_id', $catid);

            //  Featured switch
            switch ($show_front)
            {
                case 1:
                    $model->setState('filter.featured', 'show');
                    break;
                case 0:
                    $model->setState('filter.featured', 'hide');
                    break;
                default:
                    $model->setState('filter.featured', 'only');
                    break;
            }

            $ordering = explode(' ', $orderby);
            $model->setState('list.ordering', $ordering[0]);
            $model->setState('list.direction', isset($ordering[1]) ? $ordering[1] : null);

            $rows = $model->getItems();
            // end Joomla specific
        }

        // Process the prepare content plugins
        JPluginHelper::importPlugin('content');

        $i = 0;
        $lists = array();
        if(count($rows)){
            foreach ($rows as $row)
            {
                $user       = JFactory::getUser();
                $dispatcher   = JDispatcher::getInstance();
                $results = @$dispatcher->trigger('onContentPrepare', array ('com_content.article', & $row, & $params, 0));

                $text = JHtml::_('content.prepare',$row->introtext);

                $lists[$i] = new stdClass();
                $lists[$i]->id = $row->id;
                $lists[$i]->title = htmlspecialchars($row->title);
                $lists[$i]->introtext = self::prepareContent($text, $text_length);
                $lists[$i]->date = new JDate($row->created);
                if ($content_type == 'joomla')
                {
                    $lists[$i]->link = JRoute::_(ContentHelperRoute::getArticleRoute($row->id, $row->catid));
                } else
                {
                    $lists[$i]->link = JRoute::_(K2HelperRoute::getItemRoute($row->id . ':' . $row->alias, $row->catid . ':' . $row->category_alias));
                }
                $i++;
            }
        }

        return $lists;
    }

}
